| Title: | Tools to support psychometric analyses at "CERMAT" |
|---|---|
| Description: | The package provides various tools and utilities to aid with analytic needs at CZVV. The package contains a SIA module that enables loading public data into the main SIA app and conducting advanced IRT modeling. |
| Authors: | Jan Netik [aut] |
| Maintainer: | Patricia Martinkova <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.6 |
| Built: | 2026-05-12 07:44:20 UTC |
| Source: | https://github.com/siaverse/EduTestItemAnalysis |
Here goes the description.
Here goes the author(s) information.